import { AST_NODE_TYPES, TSESLint, TSESTree } from "@typescript-eslint/experimental-utils";
declare type StatementType = string | {
    type?: AST_NODE_TYPES | AST_NODE_TYPES[];
    keyword?: string | string[];
    inline?: boolean;
    comment?: boolean | "line" | "block";
};
export interface PaddingOption {
    blankLine: keyof typeof PaddingTypes;
    prev: StatementType | StatementType[];
    next: StatementType | StatementType[];
}
declare type MessageIds = "expectedBlankLine" | "unexpectedBlankLine";
declare type Options = PaddingOption[];
/**
 * Check and report statements for `any` configuration.
 * It does nothing.
 * @returns
 * @internal
 */
declare function verifyForAny(): void;
/**
 * Check and report statements for `never` configuration.
 * This auto-fix removes blank lines between the given 2 statements.
 * However, if comments exist between 2 blank lines, it does not remove those
 * blank lines automatically.
 * @param context - The rule context to report.
 * @param _ - Unused. The previous node to check.
 * @param nextNode - The next node to check.
 * @param paddingLines - The array of token pairs that blank
 * lines exist between the pair.
 * @returns
 * @internal
 */
declare function verifyForNever(context: TSESLint.RuleContext<MessageIds, Options>, _: TSESTree.Node, nextNode: TSESTree.Node, paddingLines: [TSESTree.Token, TSESTree.Token][]): void;
/**
 * Check and report statements for `always` configuration.
 * This auto-fix inserts a blank line between the given 2 statements.
 * If the `prevNode` has trailing comments, it inserts a blank line after the
 * trailing comments.
 * @param context - The rule context to report.
 * @param prevNode - The previous node to check.
 * @param nextNode - The next node to check.
 * @param paddingLines - The array of token pairs that blank
 * lines exist between the pair.
 * @returns
 * @internal
 */
declare function verifyForAlways(context: TSESLint.RuleContext<MessageIds, Options>, prevNode: TSESTree.Node, nextNode: TSESTree.Node, paddingLines: [TSESTree.Token, TSESTree.Token][]): void;
/**
 * Types of blank lines.
 * `any`, `never`, and `always` are defined.
 * Those have `verify` method to check and report statements.
 * @internal
 */
declare const PaddingTypes: {
    any: {
        verify: typeof verifyForAny;
    };
    never: {
        verify: typeof verifyForNever;
    };
    always: {
        verify: typeof verifyForAlways;
    };
};
declare const _default: TSESLint.RuleModule<MessageIds, Options, TSESLint.RuleListener>;
export default _default;
//# sourceMappingURL=spacing.d.ts.map